==> ohos-hpm-cli-1.0.10.tgz: package/lib/main.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

require("@babel/polyfill");

var _commander = _interopRequireDefault(require("commander"));

var _events = _interopRequireDefault(require("events"));

var _package = require("../package.json");

var _config = require("./utils/config");

var _semver = _interopRequireDefault(require("semver"));

var _i18n = _interopRequireWildcard(require("./i18n"));

var _helpers = require("./utils/helpers");

var _commands = require("./commands");

var _log = _interopRequireDefault(require("./core/log"));

var _pluginAPI = _interopRequireDefault(require("./plugin/pluginAPI"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

/*eslint-disable*/
_events["default"].EventEmitter.defaultMaxListeners = 100;

function actionEntrance() {
  return _actionEntrance.apply(this, arguments);
}

function _actionEntrance() {
  _actionEntrance = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
    var _args = arguments;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            if (!(_semver["default"].compare(process.version, '12.0.0') === -1)) {
              _context.next = 3;
              break;
            }

            process.exitCode = -1;
            return _context.abrupt("return", _i18n["default"].log('nodejs.version'));

          case 3:
            _context.prev = 3;
            _context.next = 6;
            return (0, _commands.runAction)(this._name, _args, pluginAPI);

          case 6:
            _context.next = 13;
            break;

          case 8:
            _context.prev = 8;
            _context.t0 = _context["catch"](3);
            process.exitCode = -1;

            _i18n["default"].log("".concat(this._name, ".error"), {
              error: (0, _helpers.getErrorMessage)(_context.t0)
            });

            _log["default"].debug(_context.t0);

          case 13:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[3, 8]]);
  }));
  return _actionEntrance.apply(this, arguments);
}

(0, _config.initConfig)();

_commander["default"].version(_package.version);

_commander["default"].command('init').description((0, _i18n.getI18nMessage)('help.init')).option('-t, --template <template>', (0, _i18n.getI18nMessage)('help.initTemplate')).option('-d, --dirname <dirname>', (0, _i18n.getI18nMessage)('help.initDir')).option('-s, --scope <scopename>', (0, _i18n.getI18nMessage)('help.initScope')).arguments('[name]').action(actionEntrance);

_commander["default"].command('build').allowUnknownOption(true).description((0, _i18n.getI18nMessage)('help.build')).action(actionEntrance);

_commander["default"].command('pack').description((0, _i18n.getI18nMessage)('help.pack')).action(actionEntrance);

_commander["default"].command('dist').allowUnknownOption(true).description((0, _i18n.getI18nMessage)('help.dist')).action(actionEntrance);

_commander["default"].command('install').alias('i').alias('add').arguments('[name]').description((0, _i18n.getI18nMessage)('help.install')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.installGlobal')).option('-d, --save-dev', (0, _i18n.getI18nMessage)('help.installDev'));

_commander["default"].command('uninstall').alias('rm').alias('remove').arguments('<name>').description((0, _i18n.getI18nMessage)('help.uninstall')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.uninstallGlobal')).option('-d, --save-dev', (0, _i18n.getI18nMessage)('help.uninstallDev'));

_commander["default"].command('publish').description((0, _i18n.getI18nMessage)('help.publish')).option('-o, --old', (0, _i18n.getI18nMessage)('help.publishOld')).action(actionEntrance);

_commander["default"].command('run').allowUnknownOption(true).description((0, _i18n.getI18nMessage)('help.run')).arguments('<cmd>').action(actionEntrance);

_commander["default"].command('config').description((0, _i18n.getI18nMessage)('help.config')).action(actionEntrance).option('set <key> <value>', (0, _i18n.getI18nMessage)('help.configSet')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('delete <key>', (0, _i18n.getI18nMessage)('help.configDelete'));

_commander["default"].command('search').description((0, _i18n.getI18nMessage)('help.search')).option('-t, --type <type>', (0, _i18n.getI18nMessage)('help.searchType')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('-p, --pageSize <pageSize>', (0, _i18n.getI18nMessage)('help.searchPagesize')).option('-c, --currentPage <currentPage>', (0, _i18n.getI18nMessage)('help.searchCurrentpage')).option('-v, --version <latest|all|semver>', (0, _i18n.getI18nMessage)('help.searchVersion')).arguments('[name]').action(actionEntrance);

_commander["default"].command('update').alias('up').alias('upgrade').arguments('[name]').description((0, _i18n.getI18nMessage)('help.update')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.updateGlobal'));

_commander["default"].command('check-update').description((0, _i18n.getI18nMessage)('help.checkUpdate')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.checkUpdateGlobal')).option('-j, --json', (0, _i18n.getI18nMessage)('help.checkUpdateJson'));

_commander["default"].command('list').alias('ls').description((0, _i18n.getI18nMessage)('help.list')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('-g, --global', (0, _i18n.getI18nMessage)('help.listGlobal')).action(actionEntrance);

_commander["default"].command('gen-keys').description((0, _i18n.getI18nMessage)('help.genKeys')).action(actionEntrance);

_commander["default"].command('extract').alias('x').arguments('<source> [target]').description((0, _i18n.getI18nMessage)('help.extract')).action(actionEntrance);

_commander["default"].command('lang').arguments('[lang]').description((0, _i18n.getI18nMessage)('lang.lang')).action(actionEntrance);

var pluginAPI = new _pluginAPI["default"](process.cwd(), _commands.runAction, _commander["default"]);
pluginAPI.registerPlugins();

_commander["default"].parse(process.argv);

==> ohos-hpm-cli-1.2.0.tgz: package/lib/main.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

require("@babel/polyfill");

var _commander = _interopRequireDefault(require("commander"));

var _events = _interopRequireDefault(require("events"));

var _package = require("../package.json");

var _config = require("./utils/config");

var _semver = _interopRequireDefault(require("semver"));

var _i18n = _interopRequireWildcard(require("./i18n"));

var _helpers = require("./utils/helpers");

var _commands = require("./commands");

var _log = _interopRequireDefault(require("./core/log"));

var _pluginAPI = _interopRequireDefault(require("./plugin/pluginAPI"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

/*eslint-disable*/
_events["default"].EventEmitter.defaultMaxListeners = 100;

function actionEntrance() {
  return _actionEntrance.apply(this, arguments);
}

function _actionEntrance() {
  _actionEntrance = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
    var _args = arguments;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            if (!(_semver["default"].compare(process.version, '12.0.0') === -1)) {
              _context.next = 3;
              break;
            }

            process.exitCode = -1;
            return _context.abrupt("return", _i18n["default"].log('nodejs.version'));

          case 3:
            _context.prev = 3;
            _context.next = 6;
            return (0, _commands.runAction)(this._name, _args, pluginAPI);

          case 6:
            _context.next = 13;
            break;

          case 8:
            _context.prev = 8;
            _context.t0 = _context["catch"](3);
            process.exitCode = -1;

            _i18n["default"].log("".concat(this._name, ".error"), {
              error: (0, _helpers.getErrorMessage)(_context.t0)
            });

            _log["default"].debug(_context.t0);

          case 13:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[3, 8]]);
  }));
  return _actionEntrance.apply(this, arguments);
}

(0, _config.initConfig)();

_commander["default"].version(_package.version, "-V, --version", (0, _i18n.getI18nMessage)('help.version'));

_commander["default"].helpOption("-h --help", (0, _i18n.getI18nMessage)("help.help"));

_commander["default"].addHelpCommand("help [command]", (0, _i18n.getI18nMessage)("help.help"));

_commander["default"].command('init').description((0, _i18n.getI18nMessage)('help.init')).option('-t, --template <template>', (0, _i18n.getI18nMessage)('help.initTemplate')).option('-d, --dirname <dirname>', (0, _i18n.getI18nMessage)('help.initDir')).option('-s, --scope <scopename>', (0, _i18n.getI18nMessage)('help.initScope')).arguments('[name]').action(actionEntrance);

_commander["default"].command('build').allowUnknownOption(true).description((0, _i18n.getI18nMessage)('help.build')).action(actionEntrance);

_commander["default"].command('pack').description((0, _i18n.getI18nMessage)('help.pack')).action(actionEntrance);

_commander["default"].command('dist').allowUnknownOption(true).description((0, _i18n.getI18nMessage)('help.dist')).action(actionEntrance);

_commander["default"].command('install').alias('i').alias('add').arguments('[name]').description((0, _i18n.getI18nMessage)('help.install')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.installGlobal')).option('-d, --save-dev', (0, _i18n.getI18nMessage)('help.installDev'));

_commander["default"].command('uninstall').alias('rm').alias('remove').arguments('<name>').description((0, _i18n.getI18nMessage)('help.uninstall')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.uninstallGlobal')).option('-d, --save-dev', (0, _i18n.getI18nMessage)('help.uninstallDev'));

_commander["default"].command('publish').description((0, _i18n.getI18nMessage)('help.publish')).option('-o, --old', (0, _i18n.getI18nMessage)('help.publishOld')).action(actionEntrance);

_commander["default"].command('run').allowUnknownOption(true).description((0, _i18n.getI18nMessage)('help.run')).arguments('<cmd>').action(actionEntrance);

_commander["default"].command('config').description((0, _i18n.getI18nMessage)('help.config')).action(actionEntrance).option('set <key> <value>', (0, _i18n.getI18nMessage)('help.configSet')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('delete <key>', (0, _i18n.getI18nMessage)('help.configDelete'));

_commander["default"].command('search').description((0, _i18n.getI18nMessage)('help.search')).option('-t, --type <type>', (0, _i18n.getI18nMessage)('help.searchType')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('-p, --pageSize <pageSize>', (0, _i18n.getI18nMessage)('help.searchPagesize')).option('-c, --currentPage <currentPage>', (0, _i18n.getI18nMessage)('help.searchCurrentpage')).option('-v, --version <latest|all|semver>', (0, _i18n.getI18nMessage)('help.searchVersion')).arguments('[name]').action(actionEntrance);

_commander["default"].command('update').alias('up').alias('upgrade').arguments('[name]').description((0, _i18n.getI18nMessage)('help.update')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.updateGlobal'));

_commander["default"].command('check-update').description((0, _i18n.getI18nMessage)('help.checkUpdate')).action(actionEntrance).option('-g, --global', (0, _i18n.getI18nMessage)('help.checkUpdateGlobal')).option('-j, --json', (0, _i18n.getI18nMessage)('help.checkUpdateJson'));

_commander["default"].command('list').alias('ls').description((0, _i18n.getI18nMessage)('help.list')).option('-j, --json', (0, _i18n.getI18nMessage)('help.searchJson')).option('-g, --global', (0, _i18n.getI18nMessage)('help.listGlobal')).action(actionEntrance);

_commander["default"].command('gen-keys').description((0, _i18n.getI18nMessage)('help.genKeys')).action(actionEntrance);

_commander["default"].command('extract').alias('x').arguments('<source> [target]').description((0, _i18n.getI18nMessage)('help.extract')).action(actionEntrance);

_commander["default"].command('ui').description((0, _i18n.getI18nMessage)('help.ui')).option('-p, --port <port>', (0, _i18n.getI18nMessage)('help.uiPort')).option('--deamon', (0, _i18n.getI18nMessage)('help.deamon')).action(actionEntrance);

_commander["default"].command('lang').arguments('[lang]').description((0, _i18n.getI18nMessage)('lang.lang')).action(actionEntrance);

var pluginAPI = new _pluginAPI["default"](process.cwd(), _commands.runAction, _commander["default"]);
pluginAPI.registerPlugins();

_commander["default"].parse(process.argv);
